@@ -44,12 +44,12 @@ following features:
     automatically switching mirrors if there is a failure.
 """
 
-__version__ = '3.10.2'
-__date__    = '2017/02/02'
+__version__ = '4.0.0'
+__date__    = '2019/02/25'
 __author__  = 'Michael D. Stenner <mstenner@linux.duke.edu>, ' \
               'Ryan Tomayko <rtomayko@naeblis.cx>' \
               'Seth Vidal <skvidal@fedoraproject.org>' \
               'Zdenek Pavlas <zpavlas@redhat.com>'
 __url__     = 'http://urlgrabber.baseurl.org/'
 
-from grabber import urlgrab, urlopen, urlread
+from .grabber import urlgrab, urlopen, urlread
